import os
from setuptools import setup

setup(
    name = "packageshree",
    version = "0.3",
    author = "Shridhar",
    author_email = "shridhar5697@gmail.com",
    description = ("An demonstration of how to create, document, and publish "),
    packages=['packageshree']
)